@@ -1,7 +1,7 @@
 package App::hr;
 
 our $DATE = '2015-07-06'; # DATE
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.14'; # VERSION
 
 use feature 'say';
 use strict 'subs', 'vars';
@@ -16,10 +16,14 @@ our @EXPORT_OK = qw(
 our %SPEC;
 
 # IFBUILT
-## INSERT_BLOCK_FROM_MODULE: Code::Embeddable pick
+sub pick {
+    return undef unless @_;
+    return $_[@_*rand];
+}
+
 # END IFBUILT
 # IFUNBUILT
-use Code::Embeddable; *pick = \&Code::Embeddable::pick;
+# use Code::Embeddable; *pick = \&Code::Embeddable::pick;
 # END IFUNBUILT
 
 
@@ -51,26 +55,45 @@ $SPEC{hr_app} = {
     summary => 'Print horizontal bar on the terminal',
     description => <<'_',
 
+`hr` can be useful as a marker/separator, especially if you use other commands
+that might produce a lot of output, and you need to scroll back lots of pages to
+see previous output. Example:
+
+    % hr; command-that-produces-lots-of-output
+    ============================================================================
+    Command output
+    ...
+    ...
+    ...
+
+    % hr -r; some-command; hr -r; another-command
+
+Usage:
+
     % hr
     ============================================================================
 
     % hr -c red  ;# will output the same bar, but in red
 
+    % hr --random-color  ;# will output the same bar, but in random color
+
     % hr x----
     x----x----x----x----x----x----x----x----x----x----x----x----x----x----x----x
 
-    % hr --random-pattern
-
-    % hr --random-color
-
-    % hr -r  ;# shortcut for --random-pattern --random-color
-
     % hr -- -x-  ;# specify a pattern that starts with a dash
     % hr -p -x-  ;# ditto
 
+    % hr --random-pattern
+    vvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvv
+
+    % hr --random-pattern
+    *---*---*---*---*---*---*---*---*---*---*---*---*---*---*---*---*---*---*---
+
+    % hr -r  ;# shortcut for --random-pattern --random-color
+
     % hr --help
 
-You can also use the `hr` function in `App::hr` module.
+If you use Perl, you can also use the `hr` function in `App::hr` module.
 
 _
     args_rels => {
@@ -171,7 +194,7 @@ App::hr - Print horizontal bar on the terminal
 
 =head1 VERSION
 
-This document describes version 0.13 of App::hr (from Perl distribution App-hr), released on 2015-07-06.
+This document describes version 0.14 of App::hr (from Perl distribution App-hr), released on 2015-07-06.
 
 =head1 SYNOPSIS
 
@@ -194,46 +217,63 @@ You can also use the provided CLI L<hr>.
 
 =head1 FUNCTIONS
 
-=head2 hr([PATTERN]) => optional STR
+=head2 hr([ PATTERN [, COLOR ] ]) => optional STR
 
 Print (under void context) or return (under scalar/array context) a horizontal
 ruler with the width of the terminal.
 
+Terminal width is determined using L<Term::Size>.
+
 C<PATTERN> is optional, can be multicharacter, but cannot be empty string. The
 defautl is C<=>.
 
-Under Windows, when printing, will shave one character at the end because the
-terminal cursor will move a line down when printing at the last column.
-
-Terminal width is currently determined using L<Term::App::Role::Attrs>, which
-will either use environment variable C<COLUMNS> or detecting using
-L<Term::Size>, or if all those fail, use a hard-coded default of 80.
+Under Windows, will shave one character at the end because the terminal cursor
+will move a line down when printing at the last column.
 
 
 =head2 hr_app(%args) -> [status, msg, result, meta]
 
 Print horizontal bar on the terminal.
 
-% hr
-    ============================================================================
+C<hr> can be useful as a marker/separator, especially if you use other commands
+that might produce a lot of output, and you need to scroll back lots of pages to
+see previous output. Example:
 
+ % hr; command-that-produces-lots-of-output
+ ============================================================================
+ Command output
+ ...
+ ...
+ ...
+ 
+ % hr -r; some-command; hr -r; another-command
+
+Usage:
+
+ % hr
+ ============================================================================
+ 
  % hr -c red  ;# will output the same bar, but in red
  
+ % hr --random-color  ;# will output the same bar, but in random color
+ 
  % hr x----
  x----x----x----x----x----x----x----x----x----x----x----x----x----x----x----x
  
- % hr --random-pattern
- 
- % hr --random-color
- 
- % hr -r  ;# shortcut for --random-pattern --random-color
- 
  % hr -- -x-  ;# specify a pattern that starts with a dash
  % hr -p -x-  ;# ditto
  
+ % hr --random-pattern
+ vvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvv
+ 
+ % hr --random-pattern
+ *---*---*---*---*---*---*---*---*---*---*---*---*---*---*---*---*---*---*---
+ 
+ % hr -r  ;# shortcut for --random-pattern --random-color
+ 
  % hr --help
 
-You can also use the C<hr> function in C<App::hr> module.
+If you use Perl, you can also use the C<hr> function in C<App::hr> module.
 
 Arguments ('*' denotes required arguments):
 
